@@ -47,11 +47,34 @@ def get_func_name(node: ast.Call) -> str:
         return f"{func.value.id}.{func.attr}"
     elif isinstance(func, ast.Lambda):
         return "<lambda>"
+    return "<function>"
 
 
-def is_call_attr(node: ast.Assign | ast.Expr) -> bool:
-    return isinstance(node.value, ast.Call) and isinstance(node.value.func, ast.Attribute)
+def is_attr_call(node: ast.stmt) -> bool:
+    return isinstance(node, ast.Call) and isinstance(node.func, ast.Attribute)
 
 
 def is_func(node: ast.Assign | ast.Expr, funcname: str) -> bool:
     return node.value.func.attr == funcname
+
+
+def is_if_name_equals_main(node: ast.If) -> bool:
+    return (
+        isinstance(node.test, ast.Compare)
+        and isinstance(node.test.left, ast.Name)
+        and node.test.left.id == "__name__"
+        and isinstance(node.test.comparators[0], ast.Constant)
+        and node.test.comparators[0].value == "__main__"
+    )  # doesn't check the '==', but it's good enough
+
+
+def get_ancestors(node: ast.stmt) -> list[type[ast.stmt]]:
+    result = []
+    while True:
+        if isinstance(node, ast.Module):
+            break
+        else:
+            result.append(type(node.parent))
+        node = node.parent
+
+    return result
