@@ -2,8 +2,13 @@ from __future__ import annotations
 
 import ast
 
+from flake8_tkinter.constants import BIND_METHODS
 from flake8_tkinter.rules.ast_assign import detect_assign_to_gm_return
-from flake8_tkinter.rules.ast_attribute import detect_use_of_dumb_constant
+from flake8_tkinter.rules.ast_attribute import (
+    detect_use_of_dumb_constant,
+    detect_use_of_tkinter_constant,
+    detect_use_of_tkinter_dot_message,
+)
 from flake8_tkinter.rules.ast_call import (
     detect_bind_add_is_not_boolean,
     detect_bind_add_missing,
@@ -17,7 +22,7 @@ from flake8_tkinter.rules.ast_import_from import (
     detect_from_tkinter_import_star,
 )
 from flake8_tkinter.rules.ast_loop import detect_tag_bind_in_loop_badly
-from flake8_tkinter.utils import Error, Settings
+from flake8_tkinter.utils import Error, Settings, get_ancestors
 
 
 class Visitor(ast.NodeVisitor):
@@ -31,16 +36,27 @@ class Visitor(ast.NodeVisitor):
 
     def visit_Attribute(self, node: ast.Attribute) -> None:
         self.extend(detect_use_of_dumb_constant(node))
+        self.extend(detect_use_of_tkinter_constant(node))
+        self.extend(detect_use_of_tkinter_dot_message(node))
 
         self.generic_visit(node)
 
-    def visit_Call(self, node: ast.Call) -> None:
+    def visit_BindMethod(self, node: ast.Call) -> None:
         self.extend(detect_bind_add_is_not_boolean(node))
         self.extend(detect_bind_add_missing(node))
         self.extend(detect_called_func_bind(node))
+
+    def visit_Call(self, node: ast.Call) -> None:
         self.extend(detect_called_func_command_arg(node))
         self.extend(detect_multiple_mainloop_calls(node))
 
+        if (
+            isinstance(node.func, ast.Attribute)
+            and isinstance(node.func.value, ast.Name)  # TODO: can it be something else?
+            and node.func.attr in BIND_METHODS | {"tag_bind"}
+        ):
+            self.visit_BindMethod(node)
+
         self.generic_visit(node)
 
     def visit_Import(self, node: ast.Import) -> None:
@@ -78,6 +94,27 @@ class Visitor(ast.NodeVisitor):
 
         self.generic_visit(node)
 
+    def visit_If(self, node: ast.If) -> None:
+        ancestors = get_ancestors(node)
+        if ast.For in ancestors or ast.While in ancestors:
+            self.extend(detect_tag_bind_in_loop_badly(node))
+
+        self.generic_visit(node)
+
+    def visit_With(self, node: ast.With) -> None:
+        ancestors = get_ancestors(node)
+        if ast.For in ancestors or ast.While in ancestors:
+            self.extend(detect_tag_bind_in_loop_badly(node))
+
+        self.generic_visit(node)
+
+    def visit_Try(self, node: ast.Try) -> None:
+        ancestors = get_ancestors(node)
+        if ast.For in ancestors or ast.While in ancestors:
+            self.extend(detect_tag_bind_in_loop_badly(node))
+
+        self.generic_visit(node)
+
     def extend(self, error: list[Error] | None) -> None:
         if Settings.tkinter_used and error:
             self.errors += error
